LinchPin 1.0.2 RELEASE NOTES
============================

LinchPin 1.0.2 is a bugfix release

Bug Fixes
----------

* `Make a default path for credentials <https://github.com/CentOS-PaaS-SIG/linchpin/issues/279>`_
* `Updates to beaker provisioner <https://github.com/CentOS-PaaS-SIG/linchpin/pull/288>`_
* `Recommended fixes from landscape.io <https://github.com/CentOS-PaaS-SIG/linchpin/pull/290>`_
* `Remove .yaml from output resources files <https://github.com/CentOS-PaaS-SIG/linchpin/pull/298>`_
* `installing deps requires -y flag <https://github.com/CentOS-PaaS-SIG/linchpin/pull/308>`_

Enhancements
------------

* `More documentation updates <https://github.com/CentOS-PaaS-SIG/linchpin/pull/281>`_



